pub struct CheckpointResponse {
pub checkpoint_token: String,
pub new_execution_state: Option<NewExecutionState>,
}Expand description
Response from a checkpoint operation.
Fields
checkpoint_token: StringThe new checkpoint token to use for subsequent checkpoints
new_execution_state: Option<NewExecutionState>The new execution state containing updated operations This includes service-generated values like CallbackDetails.CallbackId
Implementations