pub struct LambdaDurableServiceClient { /* private fields */ }Expand description
Lambda-based implementation of the DurableServiceClient.
This client uses the AWS Lambda REST APIs (CheckpointDurableExecution and GetDurableExecutionState) to communicate with the durable execution service.
Implementations
Sourceimpl LambdaDurableServiceClient
impl LambdaDurableServiceClient
Sourcepub fn from_aws_config(aws_config: &SdkConfig) -> Self
pub fn from_aws_config(aws_config: &SdkConfig) -> Self
Creates a new LambdaDurableServiceClient from AWS SDK config.
Sourcepub fn from_aws_config_with_user_agent(
aws_config: &SdkConfig,
sdk_name: &str,
sdk_version: &str,
) -> Self
pub fn from_aws_config_with_user_agent( aws_config: &SdkConfig, sdk_name: &str, sdk_version: &str, ) -> Self
Creates a new LambdaDurableServiceClient from AWS SDK config with a custom user-agent string appended to HTTP requests for SDK identification.
Sourcepub fn with_config(
credentials_provider: Arc<dyn ProvideCredentials>,
config: LambdaClientConfig,
) -> Self
pub fn with_config( credentials_provider: Arc<dyn ProvideCredentials>, config: LambdaClientConfig, ) -> Self
Creates a new LambdaDurableServiceClient with custom configuration.
Sourcepub fn new(_lambda_client: Client) -> Self
pub fn new(_lambda_client: Client) -> Self
Creates a new LambdaDurableServiceClient with a Lambda client (for backward compatibility). Note: This extracts the region from the Lambda client but uses direct HTTP calls.
IMPORTANT: This method requires that the Lambda client was created with credentials.
If you’re using this in a Lambda function, prefer using from_env() instead.