CustomLogger

Struct CustomLogger 

pub struct CustomLogger<D, I, W, E>
where D: Fn(&str, &LogInfo) + Send + Sync, I: Fn(&str, &LogInfo) + Send + Sync, W: Fn(&str, &LogInfo) + Send + Sync, E: Fn(&str, &LogInfo) + Send + Sync,
{ /* private fields */ }
A custom logger that delegates to user-provided closures.

This struct allows users to provide custom logging behavior without implementing the sealed Logger trait directly. Each log level can have its own closure for handling log messages.

Example

use durable_execution_sdk::context::{custom_logger, LogInfo};
use std::sync::Arc;

// Create a custom logger that prints to stdout
let logger = custom_logger(
    |msg, info| println!("[DEBUG] {}: {:?}", msg, info),
    |msg, info| println!("[INFO] {}: {:?}", msg, info),
    |msg, info| println!("[WARN] {}: {:?}", msg, info),
    |msg, info| println!("[ERROR] {}: {:?}", msg, info),
);