pub struct TracingLogger;Expand description
Default logger implementation using the tracing crate.
This logger includes the is_replay flag in all log messages to help
distinguish between fresh executions and replayed operations.
Extra fields from LogInfo are included in the tracing output as a formatted
string of key-value pairs, making them queryable in log aggregation systems.