Module duration

Module duration 

Duration type for durable execution operations.

Provides a Duration type with convenient constructors for specifying time intervals in seconds, minutes, hours, days, weeks, months, and years.

Structs

Duration
Duration type representing a time interval in seconds.