Callback

Struct Callback 

pub struct Callback<T> {
    pub callback_id: String,
    /* private fields */
}
A callback handle that can be used to wait for external signals.

The callback ID can be shared with external systems, which can then signal completion by calling the Lambda durable execution callback API.

Fields

callback_id: String

The unique callback ID

Implementations

Source

impl<T> Callback<T>

pub fn id(&self) -> &str

Returns the callback ID that external systems should use.

pub fn id_typed(&self) -> CallbackId

Returns the callback ID as a CallbackId newtype.

pub async fn result(&self) -> Result<T, DurableError>

Waits for the callback result.

This method checks if the callback has been signaled. If not, it suspends execution until the callback is received.

Returns

The callback result on success, or an error if the callback failed, timed out, or execution was suspended.