pub struct InitialExecutionState {
pub operations: Vec<Operation>,
pub next_marker: Option<String>,
}Expand description
Initial execution state containing checkpointed operations.
This is loaded when a durable execution resumes to enable replay of previously completed operations.
Fields
operations: Vec<Operation>List of previously checkpointed operations
next_marker: Option<String>Marker for pagination if there are more operations to load
Implementations