Module operation

Module operation 

Operation types for the AWS Durable Execution SDK.

This module defines the core operation types used for checkpointing and replay in durable execution workflows.

Structs

CallbackDetails
Details specific to CALLBACK type operations
CallbackOptions
Options for CALLBACK operations
ChainedInvokeDetails
Details specific to CHAINED_INVOKE type operations
ChainedInvokeOptions
Options for CHAINED_INVOKE operations
ContextDetails
Details specific to CONTEXT type operations
ContextOptions
Options for CONTEXT operations
ExecutionDetails
Details specific to EXECUTION type operations
Operation
Represents a checkpointed operation in a durable execution.
OperationUpdate
Represents an update to be checkpointed for an operation.
StepDetails
Details specific to STEP type operations
StepOptions
Options for STEP operations
WaitDetails
Details specific to WAIT type operations
WaitOptions
Options for WAIT operations

Enums

OperationAction
Action to perform on an operation during checkpoint.
OperationStatus
The status of an operation in a durable execution.
OperationType
The type of operation in a durable execution.