CustomSerDes

Struct CustomSerDes 

pub struct CustomSerDes<T, S, D>{ /* private fields */ }
A custom serializer/deserializer that delegates to user-provided closures.

This struct allows users to provide custom serialization behavior without implementing the sealed SerDes trait directly.

Type Parameters

  • T - The type to serialize/deserialize
  • S - The serialization closure type
  • D - The deserialization closure type

Example

use durable_execution_sdk::serdes::{custom_serdes, SerDes, SerDesContext, SerDesError};

// Create a custom serializer for strings that adds a prefix
let serdes = custom_serdes::<String, _, _>(
    |value, _ctx| Ok(format!("PREFIX:{}", value)),
    |data, _ctx| {
        data.strip_prefix("PREFIX:")
            .map(|s| s.to_string())
            .ok_or_else(|| SerDesError::deserialization("Missing PREFIX"))
    },
);