create_checkpoint_queue

Function create_checkpoint_queue 

pub fn create_checkpoint_queue(
    buffer_size: usize,
) -> (CheckpointSender, Receiver<CheckpointRequest>)
Creates a checkpoint queue with the given buffer size.

Returns a sender for submitting checkpoint requests and a receiver for the batcher to process them.