pub struct OperationIdentifier {
pub operation_id: String,
pub parent_id: Option<String>,
pub name: Option<String>,
}Expand description
Identifies an operation within a durable execution.
Each operation has a unique ID that is deterministically generated based on the parent context and step counter. This ensures that the same operation gets the same ID across replays.
Fields
operation_id: StringThe unique operation ID (deterministically generated)
parent_id: Option<String>The parent operation ID (None for root operations)
name: Option<String>Optional human-readable name for the operation
Implementations
Sourceimpl OperationIdentifier
impl OperationIdentifier
Sourcepub fn new(
operation_id: impl Into<String>,
parent_id: Option<String>,
name: Option<String>,
) -> Self
pub fn new( operation_id: impl Into<String>, parent_id: Option<String>, name: Option<String>, ) -> Self
Creates a new OperationIdentifier with the given values.
Sourcepub fn root(operation_id: impl Into<String>) -> Self
pub fn root(operation_id: impl Into<String>) -> Self
Creates a root operation identifier (no parent).
Sourcepub fn with_parent(
operation_id: impl Into<String>,
parent_id: impl Into<String>,
) -> Self
pub fn with_parent( operation_id: impl Into<String>, parent_id: impl Into<String>, ) -> Self
Creates an operation identifier with a parent.
Sourcepub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
Sets the name for this operation identifier.
Sourcepub fn operation_id_typed(&self) -> OperationId
pub fn operation_id_typed(&self) -> OperationId
Returns the operation ID as an OperationId newtype.
Sourcepub fn parent_id_typed(&self) -> Option<OperationId>
pub fn parent_id_typed(&self) -> Option<OperationId>
Returns the parent ID as an OperationId newtype, if present.
Sourcepub fn apply_to(&self, update: OperationUpdate) -> OperationUpdate
pub fn apply_to(&self, update: OperationUpdate) -> OperationUpdate
Applies this identifier’s parent_id and name to an OperationUpdate.
This is a convenience method to avoid repeated boilerplate when building operation updates across handlers.