pub struct Callback<T> {
pub callback_id: String,
/* private fields */
}Expand description
A callback handle that can be used to wait for external signals.
The callback ID can be shared with external systems, which can then signal completion by calling the Lambda durable execution callback API.
Fields
callback_id: StringThe unique callback ID
Implementations
Sourceimpl<T> Callback<T>where
T: Serialize + DeserializeOwned,
impl<T> Callback<T>where
T: Serialize + DeserializeOwned,
Sourcepub fn id_typed(&self) -> CallbackId
pub fn id_typed(&self) -> CallbackId
Returns the callback ID as a CallbackId newtype.
Sourcepub async fn result(&self) -> Result<T, DurableError>
pub async fn result(&self) -> Result<T, DurableError>
Waits for the callback result.
This method checks if the callback has been signaled. If not, it suspends execution until the callback is received.
Returns
The callback result on success, or an error if the callback failed, timed out, or execution was suspended.