Operation types for the AWS Durable Execution SDK.
This module defines the core operation types used for checkpointing and replay in durable execution workflows.
Structs
- Callback
Details - Details specific to CALLBACK type operations
- Callback
Options - Options for CALLBACK operations
- Chained
Invoke Details - Details specific to CHAINED_INVOKE type operations
- Chained
Invoke Options - Options for CHAINED_INVOKE operations
- Context
Details - Details specific to CONTEXT type operations
- Context
Options - Options for CONTEXT operations
- Execution
Details - Details specific to EXECUTION type operations
- Operation
- Represents a checkpointed operation in a durable execution.
- Operation
Update - Represents an update to be checkpointed for an operation.
- Step
Details - Details specific to STEP type operations
- Step
Options - Options for STEP operations
- Wait
Details - Details specific to WAIT type operations
- Wait
Options - Options for WAIT operations
Enums
- Operation
Action - Action to perform on an operation during checkpoint.
- Operation
Status - The status of an operation in a durable execution.
- Operation
Type - The type of operation in a durable execution.