pub struct CustomSerDes<T, S, D>where
T: Send + Sync,
S: Fn(&T, &SerDesContext) -> Result<String, SerDesError> + Send + Sync,
D: Fn(&str, &SerDesContext) -> Result<T, SerDesError> + Send + Sync,{ /* private fields */ }Expand description
A custom serializer/deserializer that delegates to user-provided closures.
This struct allows users to provide custom serialization behavior without
implementing the sealed SerDes trait directly.
Type Parameters
T- The type to serialize/deserializeS- The serialization closure typeD- The deserialization closure type
Example
use durable_execution_sdk::serdes::{custom_serdes, SerDes, SerDesContext, SerDesError};
// Create a custom serializer for strings that adds a prefix
let serdes = custom_serdes::<String, _, _>(
|value, _ctx| Ok(format!("PREFIX:{}", value)),
|data, _ctx| {
data.strip_prefix("PREFIX:")
.map(|s| s.to_string())
.ok_or_else(|| SerDesError::deserialization("Missing PREFIX"))
},
);Trait Implementations
Sourceimpl<T, S, D> Debug for CustomSerDes<T, S, D>where
T: Send + Sync,
S: Fn(&T, &SerDesContext) -> Result<String, SerDesError> + Send + Sync,
D: Fn(&str, &SerDesContext) -> Result<T, SerDesError> + Send + Sync,
impl<T, S, D> Debug for CustomSerDes<T, S, D>where
T: Send + Sync,
S: Fn(&T, &SerDesContext) -> Result<String, SerDesError> + Send + Sync,
D: Fn(&str, &SerDesContext) -> Result<T, SerDesError> + Send + Sync,
Sourceimpl<T, S, D> SerDes<T> for CustomSerDes<T, S, D>where
T: Send + Sync,
S: Fn(&T, &SerDesContext) -> Result<String, SerDesError> + Send + Sync,
D: Fn(&str, &SerDesContext) -> Result<T, SerDesError> + Send + Sync,
impl<T, S, D> SerDes<T> for CustomSerDes<T, S, D>where
T: Send + Sync,
S: Fn(&T, &SerDesContext) -> Result<String, SerDesError> + Send + Sync,
D: Fn(&str, &SerDesContext) -> Result<T, SerDesError> + Send + Sync,
Sourcefn serialize(
&self,
value: &T,
context: &SerDesContext,
) -> Result<String, SerDesError>
fn serialize( &self, value: &T, context: &SerDesContext, ) -> Result<String, SerDesError>
Serializes a value to a string representation. Read more
Sourcefn deserialize(
&self,
data: &str,
context: &SerDesContext,
) -> Result<T, SerDesError>
fn deserialize( &self, data: &str, context: &SerDesContext, ) -> Result<T, SerDesError>
Deserializes a string representation back to a value. Read more