pub fn create_checkpoint_queue(
buffer_size: usize,
) -> (CheckpointSender, Receiver<CheckpointRequest>)Expand description
Creates a checkpoint queue with the given buffer size.
Returns a sender for submitting checkpoint requests and a receiver for the batcher to process them.